@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,11 +7,12 @@
 #ifndef ATTACHMENTTEMPORARYFILESDIRS_H
 #define ATTACHMENTTEMPORARYFILESDIRS_H
 
+#include "mimetreeparser_export.h"
 #include <QObject>
 #include <QStringList>
-#include "mimetreeparser_export.h"
 
-namespace MimeTreeParser {
+namespace MimeTreeParser
+{
 class AttachmentTemporaryFilesDirsPrivate;
 /**
  * @brief The AttachmentTemporaryFilesDirs class
@@ -22,7 +23,7 @@ class MIMETREEPARSER_EXPORT AttachmentTemporaryFilesDirs : public QObject
     Q_OBJECT
 public:
     explicit AttachmentTemporaryFilesDirs(QObject *parent = nullptr);
-    ~AttachmentTemporaryFilesDirs();
+    ~AttachmentTemporaryFilesDirs() override;
 
     void addTempFile(const QString &file);
     void addTempDir(const QString &dir);
